pub enum Hint {
}Expand description
Hints allow you to pass extra information to the notification server.
Many of these are standardized by:
Which hints are actually implemented depends strongly on the notification server you talk to.
Usually get_capabilities() gives some clues, but the standard usually mentions much more
than is actually available.
Pass these to Notification::hint.
Variants
ActionIcons(bool)
If true, server may interpret action identifiers as named icons and display those.
Category(String)
DesktopEntry(String)
Name of the DesktopEntry representing the calling application.
In case of "firefox.desktop" use "firefox". May be used to retrieve the correct icon.
ImagePath(String)
Display the image at this path.
Resident(bool)
This does not work on all servers, however timeout=0 will do the job
SoundFile(String)
Play the sound at this path.
SoundName(String)
A themeable named sound from the freedesktop.org sound naming specification to play when the notification pops up.
Similar to icon-name, but for sounds. An example would be "message-new-instant".
SuppressSound(bool)
Suppress the notification sound.
Transient(bool)
When set, the server will treat the notification as transient and bypass the server’s persistence capability, if it exists.
X(i32)
Lets the notification point to a certain ‘x’ position on the screen.
Requires Y.
Y(i32)
Lets the notification point to a certain ‘y’ position on the screen.
Requires X.
Urgency(Urgency)
Pass a Urgency, either Low, Normal, or Critical.
Custom(String, String)
If you want to pass something entirely different.
CustomInt(String, i32)
A custom numerical (integer) hint
Invalid
Only used by this NotificationServer implementation.
Implementations