[−][src]Enum notify_rust::NotificationUrgency
Levels of Urgency.
Variants
LowThe behaviour for Low urgency depends on the notification server.
NormalThe behaviour for Normal urgency depends on the notification server.
CriticalA critical notification will not time out.