Timeout

Enum Timeout 

pub enum Timeout {
    Default,
    Never,
    Milliseconds(u32),
}
Describes the timeout of a notification

FromStr

You can also parse a Timeout from a &str.

assert_eq!("default".parse(), Ok(Timeout::Default));
assert_eq!("never".parse(), Ok(Timeout::Never));
assert_eq!("42".parse(), Ok(Timeout::Milliseconds(42)));

Variants



Default

Expires according to server default.

Whatever that might be…



Never

Do not expire, user will have to close this manually.



Milliseconds(u32)

Expire after n milliseconds.